@@ -1157,7 +1157,7 @@ def find_library(
 
 
 def get_robot_library_html_doc_str(
-    name: str, working_dir: str = ".", base_dir: str = ".", theme: Optional[str] = None
+    name: str, args: Optional[str], working_dir: str = ".", base_dir: str = ".", theme: Optional[str] = None
 ) -> str:
     from robot.libdocpkg import LibraryDocumentation
     from robot.libdocpkg.htmlwriter import LibdocHtmlWriter
@@ -1169,7 +1169,7 @@ def get_robot_library_html_doc_str(
     elif Path(name).suffix.lower() in ALLOWED_LIBRARY_FILE_EXTENSIONS:
         name = find_file(name, working_dir, base_dir, file_type="Library")
 
-    robot_libdoc = LibraryDocumentation(name)
+    robot_libdoc = LibraryDocumentation(name + ("::" + args if args else ""))
     robot_libdoc.convert_docs_to_html()
     with io.StringIO() as output:
         if get_robot_version() > (6, 0):
@@ -1468,6 +1468,25 @@ def _find_variables_internal(
     return (result, robot_variables)
 
 
+def resolve_args(
+    args: Tuple[Any, ...],
+    working_dir: str = ".",
+    base_dir: str = ".",
+    command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
+    variables: Optional[Dict[str, Optional[Any]]] = None,
+) -> Tuple[Any, ...]:
+    robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
+
+    result = []
+    for arg in args:
+        if isinstance(arg, str):
+            result.append(robot_variables.replace_string(arg, ignore_errors=True))
+        else:
+            result.append(arg)
+
+    return tuple(result)
+
+
 def find_variables(
     name: str,
     working_dir: str = ".",
